# -*- coding: utf-8 -*-
# Copyright 2020 Red Hat
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
import logging
from datetime import datetime
from collections import defaultdict

logger = logging.getLogger(__name__)


def component_is_inactive_for_more_than_X_days(component, days: int):
    now = datetime.today()
    last_update = datetime.strptime(component["updated_at"], "%Y-%m-%dT%H:%M:%S.%f")
    days_since_last_update = (now - last_update).days
    return component["state"] == "inactive" and days_since_last_update > days


def not_in_latest_x_components_per_type_and_tags(
    components, ordered_tags=list(), max_nb_components=2
):
    components_invalid = []
    nb_components_per_type_and_tag = defaultdict(int)
    for component in components:
        component_type = component["type"]
        component_tags = component["tags"]
        for tag in ordered_tags:
            if component_tags and tag in component_tags:
                component_type += f":{tag}"
                break
        nb_components_per_type_and_tag[component_type] += 1
        if nb_components_per_type_and_tag[component_type] > max_nb_components:
            components_invalid.append(component)
    return components_invalid
