import logging
from logging.handlers import SMTPHandler
import os

from dcifeeder import settings


def configure_feeder_logger():
    logging.basicConfig(format=settings.LOG_FORMAT)
    logging.getLogger("dcifeeder").setLevel(settings.LOG_LEVEL)
    credentials = (
        (
            settings.SMTP_USERNAME,
            settings.SMTP_PASSWORD,
        )
        if settings.SMTP_USERNAME
        else None
    )
    mail_handler = SMTPHandler(
        mailhost=(settings.SMTP_HOST, settings.SMTP_PORT),
        fromaddr=settings.FROM_ADDR,
        toaddrs=settings.ADMINS,
        subject="[DCI][ERROR] Error log in dci-feeder-api",
        credentials=credentials,
    )
    mail_handler.setLevel(logging.ERROR)
    logging.getLogger().addHandler(mail_handler)


def configure_worker_logger(event_id):
    configure_feeder_logger()
    formatter = logging.Formatter(settings.LOG_FORMAT)
    worker_handler = logging.FileHandler(
        os.path.join(settings.LOG_DIR, event_id), mode="a"
    )
    worker_handler.setLevel(logging.INFO)
    worker_handler.setFormatter(formatter)
    logging.getLogger().addHandler(worker_handler)

    if settings.LOG_LEVEL < logging.INFO:
        worker_debug_handler = logging.FileHandler(
            os.path.join(settings.LOG_DIR, f"{event_id}.debug"), mode="a"
        )
        worker_debug_handler.setLevel(logging.DEBUG)
        worker_debug_handler.setFormatter(formatter)
        logging.getLogger().addHandler(worker_debug_handler)
