# -*- coding: utf-8 -*-
# Copyright 2018 Yanis Guenane  <yanis@guenane.org>
# Author: Yanis Guenane  <yanis@guenane.org>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import logging
import os

#######
#
# Important notice. These are the default values for the settings.
# If you want to override some/all of these, either:
#
# - Set the corresponding environment variable
# or
# - Override the setting in `local_settings.py` file in the same folder
#   (which you may need to create)
#
#######

# General Parameters for dci-feeder-api
#
LOG_DIR = os.getenv("LOG_DIR", "/var/www/html")
CACHE_DIR = os.getenv("CACHE_DIR", "/var/cache/dci-feeder-api")
HOST = os.getenv("DCIFEEDERAPI_HOST", "127.0.0.1")
PORT = int(os.getenv("DCIFEEDERAPI_PORT", "5000"))


# DCI Information
#
DCI_CS_URL = os.getenv("DCI_CS_URL", "https://api.distributed-ci.io")
DCI_CLIENT_ID = os.getenv("DCI_CLIENT_ID")
DCI_API_SECRET = os.getenv("DCI_API_SECRET")
# if API credentials are not set, these will be used as fallback
DCI_LOGIN = os.getenv("DCI_LOGIN", "admin")
DCI_PASSWORD = os.getenv("DCI_PASSWORD", "admin")

# Location where the files are pushed to be served as a yum repository
DCI_REPO_RSYNC_HOST = os.getenv("DCI_REPO_RSYNC_HOST", "root@repo.distributed-ci.io")
DCI_REPO_RSYNC_DIRECTORY = os.getenv("DCI_REPO_RSYNC_DIRECTORY", "/repo")

# S3 configuration
COMPONENTS_S3_BUCKET = os.getenv("STORE_COMPONENTS_CONTAINER", "dci-components")
AWS_ACCESS_KEY_ID = os.getenv("AWS_ACCESS_KEY_ID", "minioadmin")
AWS_SECRET_ACCESS_KEY = os.getenv("AWS_SECRET_ACCESS_KEY", "minioadmin")
AWS_REGION = os.getenv("AWS_REGION", "us-east-1")
S3_ENDPOINT_URL = os.getenv("S3_ENDPOINT_URL", "http://minio:9000")
AWS_SIGNATURE_VERSION = os.getenv("AWS_SIGNATURE_VERSION", "v4")

# Data retention

SOFT_DELETE_EXPIRATION_DAYS = os.getenv("SOFT_DELETE_EXPIRATION_DAYS", 7)

# Registry Information
#
DEST_REGISTRY_URL = os.getenv("DEST_REGISTRY_URL", "registry.distributed-ci.io")
DEST_REGISTRY_USER = os.getenv("DEST_REGISTRY_USER", "admin")
DEST_REGISTRY_PASSWORD = os.getenv("DEST_REGISTRY_PASSWORD", "admin")
DEST_REGISTRY_INSECURE = bool(os.getenv("DEST_REGISTRY_INSECURE", False))

# Docker Information
DOCKER_TIMEOUT = os.getenv("DOCKER_TIMEOUT", 180)

# Logging configuration
LOG_LEVEL = logging.DEBUG
LOG_FORMAT = "[%(asctime)s] [%(process)d] [%(levelname)s] %(name)s - %(message)s"

SMTP_HOST = os.getenv("SMTP_HOST", "localhost")
SMTP_PORT = os.getenv("SMTP_PORT", 25)
FROM_ADDR = os.getenv("FROM_ADDR", "DCI Feeder API <alerts@distributed-ci.io>")
# ADMINS  = ('distributed-ci@redhat.com',)
ADMINS = (
    "fcharlie@redhat.com",
    "gvincent@redhat.com",
)
SMTP_USERNAME = os.getenv("SMTP_USERNAME", "")
SMTP_PASSWORD = os.getenv("SMTP_PASSWORD", "")

# GOOGLE CHAT

GOOGLE_CHAT_SPACE_ID = os.getenv("GOOGLE_CHAT_SPACE_ID", "")
GOOGLE_CHAT_KEY = os.getenv("GOOGLE_CHAT_KEY", "")
GOOGLE_CHAT_TOKEN = os.getenv("GOOGLE_CHAT_TOKEN", "")
GOOGLE_CHAT_THREAD_ID = os.getenv("GOOGLE_CHAT_THREAD_ID", "")
GOOGLE_CHAT_KNI_THREAD_ID = os.getenv("GOOGLE_CHAT_KNI_THREAD_ID", "")

# OPENSHIFT Settings
OCP_PULLSECRET_FILE = os.getenv(
    "OCP_PULLSECRET_FILE", "/etc/dci-feeder-api/pull-secret.json"
)
OCP_OC_CMD = os.getenv("OCP_OC_CMD", "/usr/local/bin/oc")

# python-RQ and workers settings
RQ_QUEUES = {
    "main": os.getenv("RQ_QUEUE_NAME", "dcifeeder"),
    "quick": os.getenv("RQ_QUEUE_NAME_QUICK", "dcifeeder_quick"),
}
RQ_JOBS_TIMEOUT = os.getenv("RQ_JOBS_DEFAULT_TIMEOUT", "10h")
RQ_REDIS_HOST = os.getenv("RQ_REDIS_HOST", "localhost")
RQ_REDIS_PORT = os.getenv("RQ_REDIS_PORT", 6379)

#    #
#   ###  WARNING! NO SETTING SHOULD BE DECLARED BELOW THIS LINE
#  # # #    SO THAT THEY CAN BE OVERRIDEN IN LOCAL_SETTINGS
# #######
try:
    from .local_settings import *  # noqa
except ImportError:
    pass

if any("DCI_REPO_RSYNC_TARGET" in v for v in [vars(), os.environ]):
    logging.critical(
        "The 'DCI_REPO_RSYNC_TARGET' configura variable is deprecated\n"
        "It has been replaced with 'DCI_REPO_RSYNC_HOST' + 'DCI_REPO_RSYNC_DIRECTORY'\n"
        "Please update your settings."
    )
