# Copyright 2018-2022 Red Hat Inc.
#
# Author: Yanis Guenane  <yanis@guenane.org>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import logging
from dcifeeder.feeder import get_topic_from_name

logger = logging.getLogger(__name__)


class BaseTopic(object):
    def __init__(self):
        self.topic = self.get_or_create_topic(self.name)
        self.id = self.topic["id"]
        self.etag = self.topic["etag"]
        self.component_types = self.topic["component_types"]
        self.product = self.topic["product"]

    def update_tags(self):
        """If the components of this topic have tags that need to be scraped
        override this method to do so."""
        pass

    def get_or_create_topic(self, name):
        return get_topic_from_name(name)
