import logging
import uuid
from dcifeeder import routine
from dcifeeder.topics.openshift import Openshift
from dcifeeder.topics.rhel import RHELTopic
from dcifeeder.components.compose import Compose
from dcifeeder.event import (
    extract_metadata_from_cts_event,
    extract_metadata_from_pungi_event,
    is_a_rhel_event,
    is_a_pungi_event,
    is_a_kni_baremetal_event,
    extract_metadata_from_kni_event,
    is_dci_openshift_event,
    extract_metadata_from_dci_openshift_event,
)


logger = logging.getLogger(__name__)


class RHELWorker:
    def handle(self, event):
        metadata = extract_metadata_from_cts_event(event)
        topic_name = "RHEL-{major}.{minor}".format(
            major=metadata["major"],
            minor=metadata["minor"],
        )
        topic = RHELTopic(topic_name, components=[Compose(metadata)])
        event_id = str(uuid.uuid4())
        logger.info(f"RHELWorker - Topic {topic.name} - Event id {event_id}")
        routine.get_jobs_queue("main").enqueue(
            routine.start_rhel_sync, args=(topic, event_id), job_id=event_id
        )
        return event_id

    def accepts(self, event):
        return is_a_rhel_event(event)


class QEKNIWorker:
    def handle(self, event):
        metadata = extract_metadata_from_kni_event(event)
        event_id = str(uuid.uuid4())
        logger.info(f"QEKNIWorker - Event id {event_id}")
        routine.get_jobs_queue("quick").enqueue(
            routine.tag_ocp_component, args=(metadata, event_id), job_id=event_id
        )
        return event_id

    def accepts(self, event):
        return is_a_kni_baremetal_event(event)


class OpenShiftWorker:
    def handle(self, event):
        metadata = extract_metadata_from_dci_openshift_event(event)
        ocp_version = "{major}.{minor}".format(
            major=metadata["major"],
            minor=metadata["minor"],
        )
        topic = Openshift(ocp_version)
        event_id = str(uuid.uuid4())
        logger.info(f"OpenShiftWorker - Topic {topic.name} - Event id {event_id}")
        routine.get_jobs_queue("quick").enqueue(
            routine.start_ocp_sync, args=(topic, event_id), job_id=event_id
        )
        return event_id

    def accepts(self, event):
        return is_dci_openshift_event(event)


class RHELNoInstallWorker:
    def handle(self, event):
        metadata = extract_metadata_from_pungi_event(event)
        topic_name = "RHEL-{major}.{minor}".format(
            major=metadata["major"],
            minor=metadata["minor"],
        )
        topic = RHELTopic(topic_name, components=[Compose(metadata)])
        event_id = str(uuid.uuid4())
        logger.info(f"RHELNoInstallWorker - Topic {topic.name} - Event id {event_id}")
        routine.get_jobs_queue("main").enqueue(
            routine.start_rhel_sync, args=(topic, event_id), job_id=event_id
        )
        return event_id

    def accepts(self, event):
        return is_a_pungi_event(event)
