# DCI Feeder API (aka DCI Feeder As A Service)

The purpose of this project is to offer an easy-to-use API on top of the feeders
logic. This way, users don't have to know how feeders work to be able to run
them.

The feeder runs on http://feeder.distributed-ci.io, the URL is only
reachable from within the VPN. The machine is part of the PCTT OpenStack
cloud. As usual, members of the dci team can login running `ssh dci@feeder.distributed-ci.io`

## Table of Contents

- [Installation](#installation)
- [Configuration](#configuration)
- [Usage](#usage)
- [Enabling New Product](#enabling-new-product)
- [License](#license)
- [Contact](#contact)

## Installation

### For development

`dci-feeder-api` can easily be integrated with
[dci-dev-env](https://github.com/redhat-cip/dci-dev-env).

Just clone the `dci-feeder-api` project inside `dci-dev-env`.

You can now deploy `dci-feeder-api` by running `docker-compose -f dci.yml -f dci-feeder-api/dci-feeder.yml up feeder` and all the required services will be
started.

Various settings are defined in the `dci-feeder.yml` to use local containers
and synchronization targets during development.

The Feeder API will then be available on http://0.0.0.0:5003

### For production

`dci-feeder-api` is packaged for the CentOS operating system.
To be able to install `dci-feeder-api`, one needs to enable the DCI repository:

```
#> yum install https://packages.distributed-ci.io/dci-release.el7.noarch.rpm
```

Then install the package:

```
#> yum install dci-feeder-api
```

`dci-feeder-api` is a WSGI compliant application. To be able to run it, one
needs to install a web server. It has been tested with `httpd` + `mod_wsgi`.

```
#> yum install httpd mod_wsgi
```

Here is a snippet of a working vhost configuration

```
<VirtualHost *:80>
    DocumentRoot /usr/share/dci-feeder-api/

    WSGIScriptAlias / /usr/share/dci-feeder-api/wsgi.py
    WSGIDaemonProcess dci-feeder-api user=dci group=dci processes=2 threads=25

    <Directory /usr/share/dci-feeder-api/>
       AllowOverride None
       Require all granted
    </Directory>
</VirtualHost>
```

## Configuration

The file `/etc/dci-feeder-api/settings.py` is the configuraton file for
`dci-feeder-api`.

There are four main sections:

- Application settings
- DCI Credentials
- Destrination Registry Credentials
- (Internal) OpenShift Credentials (login w/o @redhat.com + krb)

### SELinux

As for now, the application does not support SELinux. Hence, it is run with
`selinux=disabled`.

### Enable insecure registries

Add the following in `/etc/docker/daemon.json`:

```
"insecure-registries" : ["docker-registry.engineering.redhat.com", "registry.access.redhat.com"]

```

### Add dci user in dockerroot group

Since the application is run under the `dci` user, `dci` needs to be added to
the `dockerroot` group in order to interact with the `docker` daemon.

```
#> usermod -aG dockerroot dci
```

TODO:

- acl configuration

## Usage

### GET /

Get the status of the API. (http://feeder.distributed-ci.io)

```
{
    "_status": "OK",
    "message": "Distributed CI Feeder as a Service. GET /options to see available options"
}
```

### GET /options

Get the available options the platform can fulfill.
(http://feeder.distributed-ci.io/options)

```
{
    "message": "Available call POST /openstack/osp{10,11,12,13,14,15,16}
}
```

### POST /:product/:topic

Trigger the feeder for a give product/topic pair.
(http://feeder.distributed-ci.io/openstack/osp11)

```
{
    "_status": "OK",
    "event_id": "562d62a6-6cd8-40ad-9a7b-01ea84b118af",
    "message": "Feeder for openstack/osp11 has been started."
}
```

If the product/topic pair queried does not exist, the API would return this.

```
{
    "message": "Pair openstack/osp42 does not exists. Please query GET /options.
}
```

### GET /logs/:event_id

Return the logs of the feeder procedure.
(http://feeder.distributed-ci.io/logs/7b43fbf6-b2b1-4bc4-ab36-b7f846029919)

```
09:44:18,962 dcifeeder.routine INFO Starting feeder
09:44:20,340 dcifeeder.component INFO Creating directory: /var/cache/dci-feeder-api/dci.623586c7-b8b1-4aea-8bd8-9ddd9a557af7
09:44:20,990 dcifeeder.routine INFO Product: OPENSTACK - Topic: OSP11
09:44:24,358 dcifeeder.routine INFO Component: RH7-RHOS-11.0 2018-04-02.3
09:44:24,359 dcifeeder.routine INFO Type: puddle_osp
09:44:25,706 dcifeeder.feeder INFO Component already exists: RH7-RHOS-11.0 2018-04-02.3
09:44:25,706 dcifeeder.feeder INFO Status: UNCHANGED
```

## Enabling new product

`dci-feeder-api` implements a specific filesystem hierarchy to create new
products.

```
├── dcifeeder
[...]
│   ├── products
│   │   ├── __init__.py
│   │   └── openstack
│   │       ├── components
│   │       │   ├── __init__.py
│   │       │   ├── osp.py
│   │       ├── __init__.py
│   │       └── topics
│   │           ├── __init__.py
│   │           ├── osp.py
[...]

```

To enable a new product, create a submodule the way `openstack` was created and
two submodules `components` and `topics` implementing the business logic for the
import.

Every component should inherit from `dcifeeder.component.BaseComponent`.
Every topic should inherits from `dcifeeder.topic.BaseTopic`.

## Uploading manually an OpenShift component

To manually upload an OpenShift, just send a POST request on /events with `DCI_OPENSHIFT_EVENT` event type.

    requests.post("http://feeder.distributed-ci.io/events", json={
        "msg": {
            "product": "OpenShift",
            "version": "4.10.8",
            "tags": ["build:candidate"],
            "release_txt_url": "https://mirror.openshift.com/pub/openshift-v4/clients/ocp/4.10.8/release.txt",
        },
        "headers": {"EVENT_TYPE": "DCI_OPENSHIFT_EVENT"},
    })

## License

Apache 2.0

## Author Information

Distributed-CI Team <distributed-ci@redhat.com>
